import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart';
import 'package:shared_preferences/shared_preferences.dart';

const _kLocaleStorageKey = '__locale_key__';

class FFLocalizations {
  FFLocalizations(this.locale);

  final Locale locale;

  static FFLocalizations of(BuildContext context) =>
      Localizations.of<FFLocalizations>(context, FFLocalizations)!;

  static List<String> languages() => ['pt', 'en'];

  static late SharedPreferences _prefs;
  static Future initialize() async =>
      _prefs = await SharedPreferences.getInstance();
  static Future storeLocale(String locale) =>
      _prefs.setString(_kLocaleStorageKey, locale);
  static Locale? getStoredLocale() {
    final locale = _prefs.getString(_kLocaleStorageKey);
    return locale != null && locale.isNotEmpty ? createLocale(locale) : null;
  }

  String get languageCode => locale.toString();
  String? get languageShortCode =>
      _languagesWithShortCode.contains(locale.toString())
          ? '${locale.toString()}_short'
          : null;
  int get languageIndex => languages().contains(languageCode)
      ? languages().indexOf(languageCode)
      : 0;

  String getText(String key) =>
      (kTranslationsMap[key] ?? {})[locale.toString()] ?? '';

  String getVariableText({
    String? ptText = '',
    String? enText = '',
  }) =>
      [ptText, enText][languageIndex] ?? '';

  static const Set<String> _languagesWithShortCode = {
    'ar',
    'az',
    'ca',
    'cs',
    'da',
    'de',
    'dv',
    'en',
    'es',
    'et',
    'fi',
    'fr',
    'gr',
    'he',
    'hi',
    'hu',
    'it',
    'km',
    'ku',
    'mn',
    'ms',
    'no',
    'pt',
    'ro',
    'ru',
    'rw',
    'sv',
    'th',
    'uk',
    'vi',
  };
}

class FFLocalizationsDelegate extends LocalizationsDelegate<FFLocalizations> {
  const FFLocalizationsDelegate();

  @override
  bool isSupported(Locale locale) {
    final language = locale.toString();
    return FFLocalizations.languages().contains(
      language.endsWith('_')
          ? language.substring(0, language.length - 1)
          : language,
    );
  }

  @override
  Future<FFLocalizations> load(Locale locale) =>
      SynchronousFuture<FFLocalizations>(FFLocalizations(locale));

  @override
  bool shouldReload(FFLocalizationsDelegate old) => false;
}

Locale createLocale(String language) => language.contains('_')
    ? Locale.fromSubtags(
        languageCode: language.split('_').first,
        scriptCode: language.split('_').last,
      )
    : Locale(language);

final kTranslationsMap = <Map<String, Map<String, String>>>[
  // homePage
  {
    'lyiat6s2': {
      'pt': 'NOME DO MORADOR',
      'en': 'RESIDENT\'S NAME',
    },
    '3jgvv75o': {
      'pt': '',
      'en': '',
    },
    'dlaeicxd': {
      'pt': 'Auto-Visita',
      'en': 'Self-Visit',
    },
    '53jd930v': {
      'pt': 'Condominio',
      'en': 'Condominium',
    },
    'ptsx0rln': {
      'pt': 'Cadastrar Pet',
      'en': 'Register Pet',
    },
    'rgxgw626': {
      'pt': 'Cadastrar Visitante',
      'en': 'Register Visitor',
    },
    'j2tn9lpw': {
      'pt': 'QR Code de Acesso',
      'en': 'Access QR Code',
    },
    '9weuwgs1': {
      'pt': 'Histórico de Acesso',
      'en': 'Access History',
    },
    'vuk5bjau': {
      'pt': 'Agendar Visita',
      'en': 'Schedule Visit',
    },
    'xx0db4wi': {
      'pt': 'Sair',
      'en': 'Logout',
    },
    'rg9pzkpz': {
      'pt': 'FRE ACCESS',
      'en': 'FREE ACCESS',
    },
    'mp6igsok': {
      'pt': 'Home',
      'en': '',
    },
  },
  // registerVisitorPage
  {
    'p4ftwxcy': {
      'pt': 'Clique para adicionar a foto para o visitante',
      'en': 'Click to add photo for visitor',
    },
    'zazj5d8b': {
      'pt': 'Preencha o formulário com os dados do visitante',
      'en': 'Fill in the form with the visitor\'s data',
    },
    'v7g73yik': {
      'pt': 'Nome',
      'en': 'Name',
    },
    'rl8tvwnr': {
      'pt': 'Documento',
      'en': 'Document',
    },
    'yp23q90m': {
      'pt': 'Selecione o tipo:',
      'en': 'Select type:',
    },
    'n8vddmcq': {
      'pt': 'Visitante ',
      'en': 'Visitor',
    },
    '9luaa09e': {
      'pt': 'Prestador de Serviço',
      'en': 'Service provider',
    },
    'pmezihb4': {
      'pt': 'Selecione...',
      'en': 'Please select...',
    },
    'yza6i4t7': {
      'pt': 'Search for an item...',
      'en': '',
    },
    'bqpucwh0': {
      'pt': 'Contatos',
      'en': 'Contacts',
    },
    'h84ls2r6': {
      'pt': 'Telefone',
      'en': 'Telephone',
    },
    'fqp7qmka': {
      'pt': 'Email',
      'en': 'Email',
    },
    'okbw0aiu': {
      'pt': 'Cadastrar',
      'en': 'Register',
    },
    'megskb6s': {
      'pt': 'Cadastro Visitante',
      'en': 'Visitor Registration',
    },
    'xtcz66ar': {
      'pt': 'registerVisitor',
      'en': '',
    },
  },
  // scheduleCompleteVisitPage
  {
    '61lcxdgm': {
      'pt': 'Agendar Visita',
      'en': 'Schedule Visit',
    },
    'ueth1f4g': {
      'pt': 'Cadastrar Visita',
      'en': 'Register Visit',
    },
    'u0jocx7e': {
      'pt': 'Quais visitantes você deseja cadastrar?',
      'en': 'Which visitors do you want to register?',
    },
    'r8soavtz': {
      'pt': 'Clique para adicionar um visitante',
      'en': 'Click to add a visitor',
    },
    '98evnbbe': {
      'pt': 'Qual o período de validade da visita?',
      'en': 'Visit Validity Period',
    },
    'qygj6ra5': {
      'pt': 'Inicio da Visita',
      'en': 'Start of Visit',
    },
    'bv2edxku': {
      'pt': '',
      'en': 'End of Visit',
    },
    '53cbwqh9': {
      'pt': 'Quando você inicia a visita?',
      'en': 'When do you start the visit?',
    },
    'p4ws3t66': {
      'pt': 'Fim da Visita',
      'en': 'End of Visit',
    },
    'yw6d2jj8': {
      'pt': '',
      'en': 'End of Visit',
    },
    'xpgc5e8d': {
      'pt': 'Quando a visita terminá?',
      'en': 'When will the visit end?',
    },
    '0meymh6u': {
      'pt': 'Quais são os motivos da visita?',
      'en': 'What are the reasons for the visit?',
    },
    '2f68zi9t': {
      'pt': 'Motivo da Visita',
      'en': 'End of Visit',
    },
    '6p3e0bzr': {
      'pt': 'Escolha um motivo aqui',
      'en': 'Choose a reason here',
    },
    'taxe2jy2': {
      'pt': 'Search for an item...',
      'en': '',
    },
    'il4di4ln': {
      'pt': 'Nível de Acesso',
      'en': 'End of Visit',
    },
    '2wun8p6c': {
      'pt': 'Escolha um nível de acesso aqui',
      'en': 'Choose an access level here',
    },
    'stweh7pd': {
      'pt': 'Search for an item...',
      'en': '',
    },
    '8rk26eg1': {
      'pt': 'Visita se encerra após o primeiro acesso?',
      'en': 'Does the visit end after the first access?',
    },
    'lgv0q5ht': {
      'pt': 'Visita única',
      'en': 'Single visit',
    },
    'eftcs67c': {
      'pt': 'Você tem alguma observação sobre está visita?',
      'en': 'Do you have any observations about this visit?',
    },
    't0q2vuup': {
      'pt': 'Observações da Visita',
      'en': 'Visit Observations',
    },
    'w18iztdm': {
      'pt': 'Escreva as suas observações aqui',
      'en': 'Write your observations here',
    },
    'k4uraqam': {
      'pt': 'Histórico de Visitas',
      'en': 'Visit History',
    },
    'i46frqyi': {
      'pt': 'Visitante:  ',
      'en': 'Visitor:',
    },
    '73b1kj59': {
      'pt': 'Início em: ',
      'en': 'Beginning in:',
    },
    'klzzrfbn': {
      'pt': 'Fim em: ',
      'en': 'End in:',
    },
    'v3mpyspm': {
      'pt': 'scheduleVisit',
      'en': '',
    },
  },
  // scheduleProvisionalVisitPage
  {
    'x7at46ur': {
      'pt': 'Quais visitantes você deseja cadastrar?',
      'en': 'Which visitors do you want to register?',
    },
    'shj19b2o': {
      'pt': 'Qual o período de validade da visita?',
      'en': 'Visit Validity Period',
    },
    '8zgsw5so': {
      'pt': 'Ínicio da Visita',
      'en': 'Start of the Visit',
    },
    'p16wm7kp': {
      'pt': 'Quando a visitas se inicia?',
      'en': 'When does the visit start?',
    },
    '3zfd7uf9': {
      'pt': 'Qual o nome do visitante?',
      'en': 'What is the visitor\'s name?',
    },
    'wehvxbz4': {
      'pt': 'Nome do Visitante',
      'en': 'Visitor Name',
    },
    'juh7f24w': {
      'pt': 'Escreva o nome do visitante aqui',
      'en': 'Write the visitor\'s name here',
    },
    'jhss056s': {
      'pt': 'Você tem alguma observação sobre está visita?',
      'en': 'Do you have any observations about this visit?',
    },
    'cw8b3tbb': {
      'pt': 'Observações da Visita',
      'en': 'Visit Observations',
    },
    'k4qkbv1f': {
      'pt': 'Escreva as suas observações aqui',
      'en': 'Write your observations here',
    },
    'cifgwfxs': {
      'pt': 'Agendamento Provisório',
      'en': 'Provisional Scheduling',
    },
    'lhzhh2jb': {
      'pt': 'scheduleVisit',
      'en': '',
    },
  },
  // peopleOnThePropertyPage
  {
    'nsu13r5d': {
      'pt': 'Pessoas na Propriedade',
      'en': 'People on the Property',
    },
    'qv3fubdf': {
      'pt': 'Home',
      'en': '',
    },
  },
  // acessHistoryPage
  {
    'ch8qymga': {
      'pt': 'Histórico de Acesso',
      'en': 'Access History',
    },
    '2odgr6hg': {
      'pt': 'Entrou: ',
      'en': 'Access:',
    },
    'zrde3fke': {
      'pt': 'Setor',
      'en': 'Drive:',
    },
    '5uzkio93': {
      'pt': 'Home',
      'en': '',
    },
  },
  // liberationHistory
  {
    'dy0mx15f': {
      'pt': 'Pesquise aqui',
      'en': 'Search here',
    },
    'dkzewokx': {
      'pt': 'Date:',
      'en': 'Shipping:',
    },
    '2s9avwbq': {
      'pt': 'Motivo:',
      'en': 'Reason:',
    },
    '784f83pc': {
      'pt': 'Histórico de Liberação',
      'en': 'Liberation History',
    },
    '1skj43ye': {
      'pt': 'Home',
      'en': '',
    },
  },
  // signInPage
  {
    'kosqqghj': {
      'pt': 'Home',
      'en': '',
    },
  },
  // signUpPage
  {
    'bq5k4yne': {
      'pt': 'Home',
      'en': '',
    },
  },
  // welcomePage
  {
    'byab1t50': {
      'pt': 'Home',
      'en': '',
    },
  },
  // visitorDetailsModalTemplateComponent
  {
    'kqzf7nx2': {
      'pt': 'Nome do Visitante',
      'en': 'Visitor Name',
    },
    'hz7ivuqn': {
      'pt': 'Tipo de Visitante',
      'en': 'Visitor Type',
    },
    'rwqn0det': {
      'pt': '(00) 0 0000-0000',
      'en': 'Telephone',
    },
    '0wqbiekp': {
      'pt': 'email@provider.etc',
      'en': 'Email',
    },
  },
  // optModal
  {
    '0enrtljz': {
      'pt': 'Pesquise aqui.....',
      'en': 'Search here.....',
    },
    'l7tw8b92': {
      'pt': 'Tipo de Pessoa',
      'en': 'Type of Person',
    },
    'oonqk812': {
      'pt': 'Morador',
      'en': 'Resident',
    },
    'yfj9pd6k': {
      'pt': 'Filtro',
      'en': 'Filter',
    },
    'svfcf5xs': {
      'pt': 'Morador',
      'en': '',
    },
    'pepv7gl9': {
      'pt': 'Tipo de Acesso',
      'en': 'Access Type',
    },
    '580z80ct': {
      'pt': 'Entrada',
      'en': 'Prohibited',
    },
    '1nbwqtzs': {
      'pt': 'Saida',
      'en': 'Exit',
    },
    '5zn9x69v': {
      'pt': 'Entrada',
      'en': '',
    },
    '8uf522zq': {
      'pt': 'Saida',
      'en': '',
    },
    '88kshkph': {
      'pt': 'Salvar',
      'en': 'Apply',
    },
  },
  // throwException
  {
    'e58xxxiq': {
      'pt': 'ERRO',
      'en': 'ERROR',
    },
  },
  // regisiterVistorTemplateComponent
  {
    'wnhkedzt': {
      'pt': 'Cadastrar Visitante',
      'en': 'Register Visitor',
    },
    'kpd31z4d': {
      'pt': 'Clique para adicionar a foto para o visitante',
      'en': 'Click to add photo for visitor',
    },
    'q986vs4m': {
      'pt': 'Preencha o formulário com os dados do visitante',
      'en': 'Fill in the form with the visitor\'s data',
    },
    'llcw2tei': {
      'pt': 'Nome',
      'en': 'Name',
    },
    '67ykbznt': {
      'pt': 'Selecione o tipo:',
      'en': 'Select type:',
    },
    'ugjkeiz7': {
      'pt': 'Visitante ',
      'en': 'Visitor',
    },
    '8nlk5xlk': {
      'pt': 'Prestador de Serviço',
      'en': 'Service provider',
    },
    'kw07i43y': {
      'pt': 'Selecione...',
      'en': 'Please select...',
    },
    'e887o707': {
      'pt': 'Search for an item...',
      'en': '',
    },
    '96ayre48': {
      'pt': 'Documento',
      'en': 'Document',
    },
    'j0g7ggs2': {
      'pt': 'Contatos',
      'en': 'Contacts',
    },
    'ybdjabnd': {
      'pt': 'Telefone',
      'en': 'Telephone',
    },
    'tlr6uxo4': {
      'pt': 'Email',
      'en': 'Email',
    },
    '65puvap9': {
      'pt': 'Cadastrar',
      'en': 'Register',
    },
  },
  // visitorSearchModalTemplateComponent
  {
    'cjlpru1m': {
      'pt': 'Procure pelo documento do visitante ',
      'en': 'Search for the visitor\'s document',
    },
    '8i1qszba': {
      'pt': 'test',
      'en': '',
    },
    'oj12tamm': {
      'pt': 'test',
      'en': '',
    },
    '9coywebh': {
      'pt': 'Visitantes encontrados',
      'en': 'Visitors Found',
    },
    '6f5p0fv6': {
      'pt': '24',
      'en': '24',
    },
    'ug6qzyla': {
      'pt': 'Adicionar',
      'en': 'To add',
    },
  },
  // visitorNotFoundComponent
  {
    '1p9mykbj': {
      'pt': 'Usuário não encontrado',
      'en': 'User not found',
    },
    'kt937sp6': {
      'pt':
          'O documento inserido não corresponde a nenhum usuário cadastrado no sistema. Verifique o documento inserido ou adicione um novo visitante ao sistema.',
      'en':
          'The document inserted does not correspond to any user registered in the system. Check the inserted document or add a new visitor to the system.',
    },
    'y2x4nfcn': {
      'pt': 'Adicionar ',
      'en': 'To add',
    },
  },
  // viewVisitDetail
  {
    '9yu35pzg': {
      'pt': 'Encerramento da Visita',
      'en': 'Closing of the Visit',
    },
    'aj6scczp': {
      'pt': 'Início',
      'en': 'Start',
    },
    'ub084nhy': {
      'pt': 'dd/mm/yyyy',
      'en': 'dd/mm/yyyy',
    },
    'rvi5z7wg': {
      'pt': 'Término',
      'en': 'Termination',
    },
    'ixs67mrz': {
      'pt': 'dd/mm/yyyy',
      'en': 'dd/mm/yyyy',
    },
    'yxilg7ek': {
      'pt': 'Motivo da Visita',
      'en': 'Start of the Visit',
    },
    'ypeydbem': {
      'pt': 'Motivo',
      'en': 'Reason',
    },
    'dgr3pk3a': {
      'pt': 'Nível de Acesso',
      'en': 'Access Level',
    },
    'rs3d4gb8': {
      'pt': 'Nível de Acesso',
      'en': '',
    },
    'lppn9rxa': {
      'pt': 'Observações da Visita',
      'en': 'Visit Observations',
    },
  },
  // scheduleVisitDetail
  {
    '7w4fohoa': {
      'pt': 'Encerramento da Visita',
      'en': 'Closing of the Visit',
    },
    'snah4iet': {
      'pt': 'Início',
      'en': 'Start',
    },
    '0cp1e31d': {
      'pt': 'dd/mm/yyyy',
      'en': 'dd/mm/yyyy',
    },
    'abppdgz3': {
      'pt': 'Término',
      'en': 'Termination',
    },
    'kqralft4': {
      'pt': 'dd/mm/yyyy',
      'en': 'dd/mm/yyyy',
    },
    'xjxhzqqm': {
      'pt': 'Motivo da Visita',
      'en': 'Start of the Visit',
    },
    '47oezdm6': {
      'pt': 'Motivo',
      'en': 'Reason',
    },
    '2ujg7u18': {
      'pt': 'Nível de Acesso',
      'en': 'Access Level',
    },
    '3emmbbfv': {
      'pt': 'Nível de Acesso',
      'en': '',
    },
    'ritce5uw': {
      'pt': 'Observações da Visita',
      'en': 'Visit Observations',
    },
  },
  // optionSelectionModal
  {
    'bmjlmhht': {
      'pt': 'Agenda\nRapida',
      'en': 'Schedule \nVisit',
    },
    'ci8eyh2v': {
      'pt': 'Agenda\nProvisória',
      'en': 'Schedule\nProvisional',
    },
    'jj2b545b': {
      'pt': 'Agenda\nCompleta',
      'en': 'Schedule\nComplete',
    },
  },
  // menuListViewComponent
  {
    'utgue9a5': {
      'pt': 'Agendar \nVisita',
      'en': 'Schedule \nVisit',
    },
    '82b5f8yz': {
      'pt': 'Cadastrar\nVisitante',
      'en': 'Register\nVisitor',
    },
    't4ie13ut': {
      'pt': 'Vincular \nCondomínio',
      'en': 'Link\nCondominium',
    },
    'n3n76pha': {
      'pt': 'Cadastrar \nPet',
      'en': 'Register\npet',
    },
    'l6b9o7yn': {
      'pt': 'QR Code \nde Acesso',
      'en': 'QR Code\nAccess',
    },
    'rxnrtdau': {
      'pt': 'Pessoas na\nPropriedade',
      'en': 'People on\nthe Property',
    },
    'nxssjz3q': {
      'pt': 'Histórico \nde Acesso',
      'en': 'Access \nHistory',
    },
    '944g4ib1': {
      'pt': 'Histórico \nde Liberação',
      'en': 'Liberation\nHistory',
    },
  },
  // menuStaggeredViewComponent
  {
    'ee33l0ms': {
      'pt': 'Agendar \nVisita',
      'en': 'Schedule \nVisit',
    },
    'ya37l3jt': {
      'pt': 'Cadastrar\n Visitante',
      'en': 'Register\n Visitor',
    },
    'h8s3adu8': {
      'pt': 'Vincular\nCondomínio',
      'en': 'Link\nCondominium',
    },
    'j6tfixen': {
      'pt': 'Cadastrar\nPet',
      'en': 'Register\npet',
    },
    '9tli4i2x': {
      'pt': 'QR Code\nde Acesso',
      'en': 'QR Code\nAccess',
    },
    'i22hecs8': {
      'pt': 'Pessoas na\nPropriedade',
      'en': 'People on\nthe Property',
    },
    '6jzghbyi': {
      'pt': 'Histórico\nde Acesso',
      'en': 'Access\nHistory',
    },
    'u8qu4v6q': {
      'pt': 'Histórico\nde Liberação',
      'en': 'Liberation\nHistory',
    },
  },
  // messageWellComponent
  {
    '8fworxmb': {
      'pt': 'Mural de Mensagens',
      'en': 'Message Wall',
    },
    'yikill36': {
      'pt': 'Todos',
      'en': 'All',
    },
  },
  // signInTemplateComponent
  {
    '9hbdjxrz': {
      'pt': 'VAMOS LA! ENTRE COM A SUA CONTA',
      'en': 'LET\'S GO! SIGN IN WITH YOUR ACCOUNT',
    },
    '1ltg0ylb': {
      'pt': 'Email',
      'en': 'Email',
    },
    '2x19ce8k': {
      'pt': 'Senha',
      'en': 'Password',
    },
    'xhnawzcb': {
      'pt': 'Campo é necessário',
      'en': 'Field is required',
    },
    '2ib9bf67': {
      'pt': 'Please choose an option from the dropdown',
      'en': '',
    },
    '9cs5wlmc': {
      'pt': 'Campo é necessário',
      'en': 'Field is required',
    },
    'rkxwb0sg': {
      'pt': 'Please choose an option from the dropdown',
      'en': '',
    },
    'k44tm7wo': {
      'pt': 'Entrar',
      'en': 'Sign-In',
    },
    '14u7ipws': {
      'pt': 'Cadastrar',
      'en': 'Sign-Up',
    },
    '1x926nsn': {
      'pt': 'Entrar',
      'en': 'Sign-In',
    },
    'jwvd4ai1': {
      'pt': 'Cadastrar',
      'en': 'Sign-Up',
    },
    '05dx91ku': {
      'pt': 'Você esqueceu a sua senha?',
      'en': 'Have you forgotten your password?',
    },
    'p5c6d54y': {
      'pt': '  Recupere aqui',
      'en': 'recover here',
    },
    'olf967cj': {
      'pt': 'Termo de Uso',
      'en': 'Terms of use',
    },
  },
  // signUpTemplateComponent
  {
    '49609olv': {
      'pt': 'INSIRA SEU EMAIL E SENHA, VAMOS TE CADASTRAR!',
      'en': 'ENTER YOUR EMAIL AND PASSWORD, LET\'S REGISTER YOU!',
    },
    '3corpwhd': {
      'pt': 'Nome',
      'en': 'Name',
    },
    '80wonb69': {
      'pt': 'Email',
      'en': 'Email',
    },
    'ws143wf4': {
      'pt': '',
      'en': '',
    },
    '0firji8l': {
      'pt': 'Senha',
      'en': 'Password',
    },
    '3bs10dfq': {
      'pt': 'Campo é necessário',
      'en': 'Field is required',
    },
    'ph22karc': {
      'pt': 'Please choose an option from the dropdown',
      'en': '',
    },
    'mlvw63yj': {
      'pt': 'Campo é necessário',
      'en': 'Field is required',
    },
    'z0bv6wi2': {
      'pt': 'Please choose an option from the dropdown',
      'en': '',
    },
    '6nn79lmh': {
      'pt': 'Campo é necessário',
      'en': 'Field is required',
    },
    'rcikqhf1': {
      'pt': 'Please choose an option from the dropdown',
      'en': '',
    },
    'rnvdwzei': {
      'pt': 'Cadastrar-se',
      'en': 'Sign-Up',
    },
    'a9smhn5b': {
      'pt': 'Você já tem uma conta? ',
      'en': 'You already have an account?',
    },
    '09xv5ctc': {
      'pt': 'Clique aqui',
      'en': 'Click here',
    },
    'huygnka2': {
      'pt': 'Termo de Uso',
      'en': '',
    },
  },
  // welcomeTemplateComponent
  {
    'dsc9tuc8': {
      'pt': 'UMA EXPERIÊCIA COMPLETA',
      'en': 'A COMPLETE EXPERIENCE',
    },
    '5bgqn16z': {
      'pt': 'COM CONFORTO ONDE VOCÊ ESTIVER.',
      'en': 'WITH COMFORT WHEREVER YOU ARE.',
    },
    'dynet730': {
      'pt': 'Entrar',
      'en': 'Sign-In',
    },
    'hha60cg7': {
      'pt': 'Cadastrar',
      'en': 'Sign-Up',
    },
    'zvtay8ee': {
      'pt': 'Entrar',
      'en': 'Sign-In',
    },
    'o6zob50a': {
      'pt': 'Cadastrar',
      'en': 'Sign-Up',
    },
  },
  // forgotPasswordTemplateComponent
  {
    'xxm3ajsy': {
      'pt': 'ESQUECEU SUA SENHA?',
      'en': 'FORGOT YOUR PASSWORD?',
    },
    'wu2f7yzo': {
      'pt':
          'Não se preucupe nós vamos te ajudar, digite o email cadastrado no aplicativo e clique em enviar.',
      'en':
          'Don\'t worry, we will help you, enter the email registered in the application and click send.',
    },
    'mtz8l7ft': {
      'pt': 'Email',
      'en': 'Email',
    },
    'w7y5wlnv': {
      'pt': 'digite o seu email.....',
      'en': 'enter your email.....',
    },
    '74rnd5bu': {
      'pt': 'Enviar',
      'en': 'To send',
    },
  },
  // visitRequestTemplateComponent
  {
    'ivfw4j04': {
      'pt': 'Nome',
      'en': 'Name',
    },
    'ndzkqehm': {
      'pt': 'Motivo',
      'en': 'Reason',
    },
    'kt87omsz': {
      'pt': 'Mensagem',
      'en': 'Message',
    },
    'cx6sviir': {
      'pt': '',
      'en': '',
    },
    'ssz899es': {
      'pt': 'Pergunta',
      'en': 'Answer',
    },
    'nw059ym1': {
      'pt': '',
      'en': '',
    },
  },
  // accessNotificationModalTemplateComponent
  {
    'dvag09pq': {
      'pt': 'Nome',
      'en': 'Name',
    },
    'h3s0r1he': {
      'pt': 'Tipo',
      'en': 'Type',
    },
    'jveeqpdz': {
      'pt': 'Acesso',
      'en': 'Access',
    },
    '9jdmuak2': {
      'pt': 'Acionamento',
      'en': 'Drive',
    },
    '5qdmkvw3': {
      'pt': '',
      'en': '',
    },
  },
  // Miscellaneous
  {
    'i5smty81': {
      'pt': '',
      'en': 'dd/mm/yyyy',
    },
    'kw89v4f5': {
      'pt': '',
      'en': '',
    },
    '7zjyxhuq': {
      'pt': '',
      'en': '',
    },
    'd86ioepz': {
      'pt': '',
      'en': '',
    },
    'lt3ssl76': {
      'pt': '',
      'en': '',
    },
    'fng3jimx': {
      'pt': '',
      'en': '',
    },
    'fl5g3od1': {
      'pt': '',
      'en': '',
    },
    'ypvz2z2w': {
      'pt': '',
      'en': '',
    },
    '8qc8ukp7': {
      'pt': '',
      'en': '',
    },
    '2e7jypoo': {
      'pt': '',
      'en': '',
    },
    '3ns1uuql': {
      'pt': '',
      'en': '',
    },
    '6wpbd6qf': {
      'pt': '',
      'en': '',
    },
    '8lujanjg': {
      'pt': '',
      'en': '',
    },
    'uteo7q4l': {
      'pt': '',
      'en': '',
    },
    'fddqwa3t': {
      'pt': '',
      'en': '',
    },
    'qt1hznnl': {
      'pt': '',
      'en': '',
    },
    'ifdxkz4h': {
      'pt': '',
      'en': '',
    },
    'mrvjp805': {
      'pt': '',
      'en': '',
    },
    '9n5qf96i': {
      'pt': '',
      'en': '',
    },
    'lmtedmcu': {
      'pt': '',
      'en': '',
    },
    'a8q9pni2': {
      'pt': '',
      'en': '',
    },
    'awm7dfw0': {
      'pt': '',
      'en': '',
    },
    'lradbjb6': {
      'pt': '',
      'en': '',
    },
    'j9igyop7': {
      'pt': '',
      'en': '',
    },
    '7wsvuydm': {
      'pt': '',
      'en': '',
    },
    'vm22i4rf': {
      'pt': '',
      'en': '',
    },
    'uirsdmbi': {
      'pt': '',
      'en': '',
    },
    'm6r7vsdc': {
      'pt': '',
      'en': '',
    },
    'mqw2z9f3': {
      'pt': '',
      'en': '',
    },
  },
].reduce((a, b) => a..addAll(b));
